# peppa
<p align="center">
<img width="30%" src="https://github.com/skhortiuk/peppa/blob/master/static/peppa.jpg?raw=True">
</p>


# How it works
Runs autopep8 on your diff from git.

# Installation
```shell script
git clone https://github.com/skhortiuk/peppa.git peppa
cd peppa && pip install -e .
```

# How to run
```shell script
peppa
```

# Example output
<p align="center">
<img width="100%" src="https://github.com/skhortiuk/peppa/blob/master/static/example.png?raw=True">
</p>

